| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (garetxe@gmail.com) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Ggit.Enums
Contents
Description
- catchError :: IO a -> (Error -> GErrorMessage -> IO a) -> IO a
- handleError :: (Error -> GErrorMessage -> IO a) -> IO a -> IO a
- data TreeWalkMode
- data SubmoduleUpdate
- data SubmoduleRecurse
- data SubmoduleIgnore
- data StatusShow
- data ResetType
- data RemoteDownloadTagsType
- data RemoteCompletionType
- data RefType
- data RebaseOperationType
- data ProxyType
- data PackbuilderStage
- data MergeFileFavor
- data FileMode
- data Error
- data Direction
- data DiffLineType
- data DiffFormatType
- data DiffBinaryType
- data DeltaType
- data ConfigLevel
- data CloneLocal
- data BranchType
Documentation
catchError :: IO a -> (Error -> GErrorMessage -> IO a) -> IO a Source #
handleError :: (Error -> GErrorMessage -> IO a) -> IO a -> IO a Source #
Exported types
data TreeWalkMode Source #
Describes in which order a tree walk should be performed.
Constructors
| TreeWalkModePre | walk tree in pre-order |
| TreeWalkModePost | walk tree in post-order |
| AnotherTreeWalkMode Int | Catch-all for unknown values |
data SubmoduleUpdate Source #
Describes how a submodule should be updated.
Constructors
| SubmoduleUpdateCheckout | checkout the submodule. |
| SubmoduleUpdateRebase | rebase the current branch onto the commit recorded in the superproject. |
| SubmoduleUpdateMerge | merge the commit recorded in the superproject into the current branch. |
| SubmoduleUpdateNone | do not update this submodule. |
| SubmoduleUpdateDefault | not used except as static initializer when we don't want any particular update rule to be specified. |
| AnotherSubmoduleUpdate Int | Catch-all for unknown values |
data SubmoduleRecurse Source #
Options for submodule recurse.
Represents the value of submodule.$name.fetchRecurseSubmodules
Constructors
| SubmoduleRecurseNo | do no recurse into submodules. |
| SubmoduleRecurseYes | recurse into submodules. |
| SubmoduleRecurseOndemand | recurse into submodules only when commit not already in local clone. |
| AnotherSubmoduleRecurse Int | Catch-all for unknown values |
data SubmoduleIgnore Source #
Describes which submodules should be ignored.
Constructors
| SubmoduleIgnoreUnspecified | reset to on-disk value. |
| SubmoduleIgnoreNone | don't ignore any change. |
| SubmoduleIgnoreUntracked | ignore untracked files. |
| SubmoduleIgnoreDirty | ignore changes in the working directory. |
| SubmoduleIgnoreAll | never check if the submodule is dirty. |
| AnotherSubmoduleIgnore Int | Catch-all for unknown values |
data StatusShow Source #
Show options for ggit_repository_file_status_foreach. Determines which
files are included in the status.
Constructors
| StatusShowIndexAndWorkdir | receive one callback for each file,
even if the file is in both the index and the workdir (combining |
| StatusShowIndexOnly | only receive callbacks for files in the index. |
| StatusShowWorkdirOnly | only receive callbacks for files in the workdir. |
| AnotherStatusShow Int | Catch-all for unknown values |
Instances
Describes the type of reset to perform.
Constructors
| ResetTypeSoft | The head will be moved to the commit. |
| ResetTypeMixed | the head will be moved to the commit and the index will be replaced with the content of the commit tree. |
| ResetTypeHard | MIXED plus changes in working tree discarded. |
| AnotherResetType Int | Catch-all for unknown values |
data RemoteDownloadTagsType Source #
Automatic tag following option
Lets us select the --tags option to use.
Constructors
| RemoteDownloadTagsTypeUnspecified | Use the setting from the configuration. |
| RemoteDownloadTagsTypeAuto | Ask the server for tags pointing to objects we're already downloading. |
| RemoteDownloadTagsTypeNone | Don't ask for any tags beyond the refspecs. |
| RemoteDownloadTagsTypeAll | Ask for the all the tags. |
| AnotherRemoteDownloadTagsType Int | Catch-all for unknown values |
data RemoteCompletionType Source #
Argument to the completion callback which tells it which operation finished.
Constructors
| RemoteCompletionTypeDownload | download. |
| RemoteCompletionTypeIndexing | indexing. |
| RemoteCompletionTypeError | error. |
| AnotherRemoteCompletionType Int | Catch-all for unknown values |
Describes the type a reference is.
Constructors
| RefTypeInvalid | An invalid reference. |
| RefTypeOid | A reference which points at an object id. |
| RefTypeSymbolic | A reference which points at another reference. |
| RefTypeListall | All reference types. |
| AnotherRefType Int | Catch-all for unknown values |
data RebaseOperationType Source #
Type of rebase operation in-progress.
Constructors
| RebaseOperationTypePick | The given commit is to be cherry-picked. The client should commit the changes and continue if there are no conflicts. |
| RebaseOperationTypeReword | The given commit is to be cherry-picked, but the client should prompt the user to provide an updated commit message. |
| RebaseOperationTypeEdit | The given commit is to be cherry-picked, but the client should stop to allow the user to edit the changes before committing them. |
| RebaseOperationTypeSquash | The given commit is to be squashed into the previous commit. The commit message will be merged with the previous message. |
| RebaseOperationTypeFixup | The given commit is to be squashed into the previous commit. The commit message from this commit will be discarded. |
| RebaseOperationTypeExec | No commit will be cherry-picked. The client should run the given command and (if successful) continue. |
| AnotherRebaseOperationType Int | Catch-all for unknown values |
The type of proxy to use.
Constructors
| ProxyTypeNone | Do not attempt to connect through a proxy. |
| ProxyTypeAuto | Try to auto-detect the proxy from the git configuration. |
| ProxyTypeSpecified | Connect via the URL given in the options. |
| AnotherProxyType Int | Catch-all for unknown values |
data PackbuilderStage Source #
Valid stages for pack building.
Constructors
| PackbuilderStageAddingObjects | adding objects. |
| PackbuilderStageDeltafication | deltafication. |
| AnotherPackbuilderStage Int | Catch-all for unknown values |
data MergeFileFavor Source #
No description available in the introspection data.
Constructors
| MergeFileFavorNormal | No description available in the introspection data. |
| MergeFileFavorOurs | No description available in the introspection data. |
| MergeFileFavorTheirs | No description available in the introspection data. |
| MergeFileFavorUnion | No description available in the introspection data. |
| AnotherMergeFileFavor Int | Catch-all for unknown values |
No description available in the introspection data.
Constructors
| FileModeUnreadable | No description available in the introspection data. |
| FileModeTree | No description available in the introspection data. |
| FileModeBlob | No description available in the introspection data. |
| FileModeBlobExecutable | No description available in the introspection data. |
| FileModeLink | No description available in the introspection data. |
| FileModeCommit | No description available in the introspection data. |
| AnotherFileMode Int | Catch-all for unknown values |
Error codes for the GGIT_ERROR error domain.
Constructors
| ErrorGitError | A generic error for when an operation fails. |
| ErrorNotfound | Input does not exist in the scope searched. |
| ErrorExists | A reference with this name already exists. |
| ErrorAmbiguous | The given error is ambiguous. |
| ErrorBufs | The buffer is too short. |
| ErrorPassthrough | Skip and passthrough the given ODB backend. |
| ErrorIterover | The iteration has finished. |
| AnotherError Int | Catch-all for unknown values |
No description available in the introspection data.
Constructors
| DirectionFetch | No description available in the introspection data. |
| DirectionPush | No description available in the introspection data. |
| AnotherDirection Int | Catch-all for unknown values |
data DiffLineType Source #
These values describe where a line came from and will be passed to
the DiffLineCallback when iterating over a diff.
The GGIT_DIFF_LINE_FILE_HDR, GGIT_DIFF_LINE_HUNK_HDR and
GGIT_DIFF_LINE_BINARY values are only sent when the diff is being printed.
Constructors
| DiffLineTypeContext | line is part of the context. |
| DiffLineTypeAddition | line that was added. |
| DiffLineTypeDeletion | line that was removed. |
| DiffLineTypeContextEofnl | Both files have no LF at end. |
| DiffLineTypeAddEofnl | LF was added at end of file. |
| DiffLineTypeDelEofnl | LF was removed at end of file. |
| DiffLineTypeFileHdr | the file header. |
| DiffLineTypeHunkHdr | the hunk header. |
| DiffLineTypeBinary | is binary. |
| AnotherDiffLineType Int | Catch-all for unknown values |
data DiffFormatType Source #
Possible output formats for diff data.
Constructors
| DiffFormatTypePatch | full git diff. |
| DiffFormatTypePatchHeader | just the file headers of patch. |
| DiffFormatTypeRaw | like git diff --raw. |
| DiffFormatTypeNameOnly | like git diff --name-only. |
| DiffFormatTypeNameStatus | like git diff --name-status. |
| AnotherDiffFormatType Int | Catch-all for unknown values |
data DiffBinaryType Source #
When producing a binary diff, the binary data returned will be either the deflated full ("literal") contents of the file, or the deflated binary delta between the two sides (whichever is smaller).
Constructors
| DiffBinaryTypeNone | No description available in the introspection data. |
| DiffBinaryTypeLiteral | No description available in the introspection data. |
| DiffBinaryTypeDelta | No description available in the introspection data. |
| AnotherDiffBinaryType Int | Catch-all for unknown values |
Describes the type of change the delta is.
Constructors
| DeltaTypeUnmodified | unmodified. |
| DeltaTypeAdded | added. |
| DeltaTypeDeleted | deleted. |
| DeltaTypeModified | modified. |
| DeltaTypeRenamed | renamed. |
| DeltaTypeCopied | copied. |
| DeltaTypeIgnored | ignored. |
| DeltaTypeUntracked | untracked. |
| AnotherDeltaType Int | Catch-all for unknown values |
data ConfigLevel Source #
Priority level of a config file. These priority levels correspond to the natural escalation logic (from higher to lower) when searching for config entries in git.git.
Constructors
| ConfigLevelProgramdata | System-wide on Windows, for compatibility with portable git. |
| ConfigLevelSystem | System-wide configuration file. |
| ConfigLevelXdg | XDG compatible configuration file (.config/git/config). |
| ConfigLevelGlobal | User-specific configuration file, also called Global configuration file. |
| ConfigLevelLocal | Repository specific configuration file. |
| ConfigLevelApp | Application specific configuration file; freely defined by applications. |
| ConfigLevelHighest | Represents the highest level of a config file. |
| AnotherConfigLevel Int | Catch-all for unknown values |
Instances
data CloneLocal Source #
No description available in the introspection data.
Constructors
| CloneLocalAuto | No description available in the introspection data. |
| CloneLocalLocal | No description available in the introspection data. |
| CloneLocalNoLocal | No description available in the introspection data. |
| CloneLocalNoLinks | No description available in the introspection data. |
| AnotherCloneLocal Int | Catch-all for unknown values |
Instances
data BranchType Source #
The type of a branch.
Constructors
| BranchTypeLocal | specifies a local branch. |
| BranchTypeRemote | specifies a remote branch. |
| AnotherBranchType Int | Catch-all for unknown values |
Instances